nbxmpp.roster_nb

Package nbxmpp :: Module roster_nb |
[hide private]
[frames] | no frames]

# Module roster_nb

source code

Simple roster implementation. Can be used though for different tasks like mass-renaming of contacts.

Classes | [hide private]
| NonBlockingRoster Defines a plenty of methods that will allow you to manage roster. Also automatically track presences from remote JIDs taking into account that every JID can have multiple resources connected. Does not currently support 'error' presences. You can also use mapping interface for access to the internal representation of contacts in roster

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.roster_nb')`
| __package__ = ``'``nbxmpp``'``

Imports: JID, Iq, Presence, Node, NodeProcessed, NS_MUC_USER, NS_ROSTER, PlugIn, logging

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.roster_nb')

  ### __package__ Value:
      'nbxmpp'